==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/iotcentral/kotlin/inputs/AppSkuInfoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.iotcentral.kotlin.inputs

import com.pulumi.azurenative.iotcentral.inputs.AppSkuInfoArgs.builder
import com.pulumi.azurenative.iotcentral.kotlin.enums.AppSku
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Information about the SKU of the IoT Central application.
 * @property name The name of the SKU.
 */
public data class AppSkuInfoArgs(
    public val name: Output<Either<String, AppSku>>,
) : ConvertibleToJava<com.pulumi.azurenative.iotcentral.inputs.AppSkuInfoArgs> {
    override fun toJava(): com.pulumi.azurenative.iotcentral.inputs.AppSkuInfoArgs =
        com.pulumi.azurenative.iotcentral.inputs.AppSkuInfoArgs.builder()
            .name(
                name.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [AppSkuInfoArgs].
 */
@PulumiTagMarker
public class AppSkuInfoArgsBuilder internal constructor() {
    private var name: Output<Either<String, AppSku>>? = null

    /**
     * @param value The name of the SKU.
     */
    @JvmName("dscydamebfnbvkad")
    public suspend fun name(`value`: Output<Either<String, AppSku>>) {
        this.name = value
    }

    /**
     * @param value The name of the SKU.
     */
    @JvmName("kmgprljuncspticd")
    public suspend fun name(`value`: Either<String, AppSku>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The name of the SKU.
     */
    @JvmName("obuklxxtyxsngrgp")
    public fun name(`value`: String) {
        val toBeMapped = Either.ofLeft<String, AppSku>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The name of the SKU.
     */
    @JvmName("otquotfsdnqvluvt")
    public fun name(`value`: AppSku) {
        val toBeMapped = Either.ofRight<String, AppSku>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): AppSkuInfoArgs = AppSkuInfoArgs(
        name = name ?: throw PulumiNullFieldException("name"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/iotcentral/kotlin/inputs/AppSkuInfoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.iotcentral.kotlin.inputs

import com.pulumi.azurenative.iotcentral.inputs.AppSkuInfoArgs.builder
import com.pulumi.azurenative.iotcentral.kotlin.enums.AppSku
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Information about the SKU of the IoT Central application.
 * @property name The name of the SKU.
 */
public data class AppSkuInfoArgs(
    public val name: Output<Either<String, AppSku>>,
) : ConvertibleToJava<com.pulumi.azurenative.iotcentral.inputs.AppSkuInfoArgs> {
    override fun toJava(): com.pulumi.azurenative.iotcentral.inputs.AppSkuInfoArgs =
        com.pulumi.azurenative.iotcentral.inputs.AppSkuInfoArgs.builder()
            .name(
                name.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [AppSkuInfoArgs].
 */
@PulumiTagMarker
public class AppSkuInfoArgsBuilder internal constructor() {
    private var name: Output<Either<String, AppSku>>? = null

    /**
     * @param value The name of the SKU.
     */
    @JvmName("lgqgjxjmkisijoky")
    public suspend fun name(`value`: Output<Either<String, AppSku>>) {
        this.name = value
    }

    /**
     * @param value The name of the SKU.
     */
    @JvmName("ftyxvfvedcrydshs")
    public suspend fun name(`value`: Either<String, AppSku>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The name of the SKU.
     */
    @JvmName("hvsstjeixthsneru")
    public fun name(`value`: String) {
        val toBeMapped = Either.ofLeft<String, AppSku>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The name of the SKU.
     */
    @JvmName("nnwvbixrtaaxfrnf")
    public fun name(`value`: AppSku) {
        val toBeMapped = Either.ofRight<String, AppSku>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): AppSkuInfoArgs = AppSkuInfoArgs(
        name = name ?: throw PulumiNullFieldException("name"),
    )
}
